.. GWCelery documentation master file, created by
   sphinx-quickstart on Tue Dec  5 14:59:24 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

GWCelery
========

GWCelery is a simple and reliable package for annotating and orchestrating LIGO/Virgo alerts, built from widely used open source components.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   monitoring
   htcondor
   contributing
   gwcelery

.. toctree::
   :maxdepth: 1

   Git repository <http://git.ligo.org/emfollow/gwcelery>
   changes
   license

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

GWCelery is open source and is licensed under the :doc:`GNU General Public License v2 or later <license>`.
